﻿using Prism.Mvvm;
using Prism.Navigation;
using System.Threading.Tasks;

namespace Borepin.Base
{
    /// <summary>
    /// Base for all BFFH Based PageModels
    /// </summary>
    public abstract class PageModelBase : BindableBase, INavigationAware
    {
        #region Private Properties
        protected readonly INavigationService _NavigationService;
        #endregion

        #region Contructors
        public PageModelBase(INavigationService navigationService)
        {
            _NavigationService = navigationService;
        }
        #endregion

        #region Properties
        /// <summary>
        /// PageModel is Busy
        /// </summary>
        private bool _IsBusy = true;
        public bool IsBusy
        {
            get => _IsBusy;
            set => SetProperty(ref _IsBusy, value);
        }
        #endregion

        #region Data
        /// <summary>
        /// Load Data async
        /// </summary>
        /// <returns></returns>
        public abstract Task LoadData();
        #endregion

        #region INavigationAware
        public abstract void OnNavigatedFrom(INavigationParameters parameters);
        public abstract void OnNavigatedTo(INavigationParameters parameters);
        #endregion
    }
}